import React, { useContext } from 'react'
import { CircularProgress, IconButton, MenuItem, Tooltip } from '@mui/material'
import useSWR from 'swr'
import useErrors from 'src/hooks/useErrors'
import AppContext from 'src/context/AppContext'
import { useRouter } from 'next/router'
import { GlobeAltIcon } from '@heroicons/react/solid'
import Menu from '@mui/material/Menu'
import PopupState, { bindTrigger, bindMenu } from 'material-ui-popup-state'
import useAxios from 'src/hooks/useAxios'

const LanguagesDropdown = () => {
  const request = useAxios()
  const { errorHandler } = useErrors()

  const { data } = useSWR(
    'get/languages',
    () =>
      request
        .get('get/languages')
        .then(res => res.data)
        .catch(err => errorHandler(err)),
    {
      revalidateOnFocus: false,
      revalidateOnReconnect: false
    }
  )
  const { language, setLanguage, setDirection } = useContext(AppContext)
  const router = useRouter()

  const handleChange = language => {
    setLanguage(language)
    localStorage.setItem('language', language)
    setDirection(language === 'eng' ? 'ltr' : 'rtl')
    localStorage.setItem('direction', language === 'eng' ? 'ltr' : 'rtl')
    router.reload()
  }

  return (
    <>
      {data ? (
        <PopupState variant='popover' popupId='demo-popup-menu'>
          {popupState => (
            <React.Fragment>
              <Tooltip arrow title={'Languages'}>
                <IconButton size={'medium'} variant='out' color={'primary'} {...bindTrigger(popupState)}>
                  <GlobeAltIcon className={'h-6'} />
                </IconButton>
              </Tooltip>
              <Menu {...bindMenu(popupState)}>
                <MenuItem selected={language === 'eng'} onClick={() => handleChange('eng')}>
                  English
                </MenuItem>
                {data.map(item => (
                  <MenuItem key={item.id} selected={language === item.abbr} onClick={() => handleChange(item.abbr)}>
                    {item.name}
                  </MenuItem>
                ))}
              </Menu>
            </React.Fragment>
          )}
        </PopupState>
      ) : (
        <CircularProgress size={20} className={'mt-2'} />
      )}
    </>
  )
}

export default LanguagesDropdown
